<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>AutoTrim</name>
    <message>
        <location filename="../AutoTrimInit.js" line="+2"/>
        <source>Auto &amp;Trim</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Przytnij &amp;automatycznie</translation>
    </message>
</context>
</TS>
